==> postcss-instagram-0.0.0.tgz: package/index.js <==
'use strict';

var postcss = require('postcss');
module.exports = postcss.plugin('postcss-instagram', function () {
  return function (css) {

    // Filter: Kalvin
    var filterKalvin = function(decl) {
      var origRule = decl.parent,
        ruleSelectors = origRule.selectors,
        afterRuleSelectors,
        imgRuleSelectors,
        afterRule;
        kalvinRule;


          afterRuleSelectors = ruleSelectors.map(function(ruleSelector){
                return ruleSelector + ':after';
          }).join(',\n');

          imgRuleSelectors = ruleSelectors.map(function(ruleSelector){
                return ruleSelector + ' img';
          }).join(',\n');


        afterRule = origRule.cloneBefore({
          selector: afterRuleSelectors
        }).removeAll();

        kalvinRule = origRule.cloneBefore({
          selector: imgRuleSelectors
        }).removeAll();

        afterRule.append({
          prop: '-moz-box-shadow',
          value: 'inset 0 0 3em #222';
          prop: '-webkit-box-shadow',
          value: 'inset 0 0 3em #222';
        });

        origRule.append({
          prop: 'position',
          value: 'relative'
        });

        kalvinRule.append({
          prop: 'filter',
          value: 'sepia(0.3) saturate(2.2) brightness(1.3) contrast(1)'
        });

        decl.remove();
      };


      css.walkDecls('filter', function(decl) {
        switch (decl.value) {
          case 'kalvin':
            filterKalvin(decl);
            break;
        }
      });
    };
  });

==> postcss-instagram-0.0.1.tgz: package/index.js <==
'use strict';

var postcss = require('postcss');
module.exports = postcss.plugin('postcss-instagram', function () {
  return function (css) {

    // Filter: Kalvin
    var filterKalvin = function(decl) {
      var origRule = decl.parent,
        ruleSelectors = origRule.selectors,
        afterRuleSelectors,
        imgRuleSelectors,
        afterRule;
        kalvinRule;


          afterRuleSelectors = ruleSelectors.map(function(ruleSelector){
                return ruleSelector + ':after';
          }).join(',\n');

          imgRuleSelectors = ruleSelectors.map(function(ruleSelector){
                return ruleSelector + ' img';
          }).join(',\n');


        afterRule = origRule.cloneBefore({
          selector: afterRuleSelectors
        }).removeAll();

        kalvinRule = origRule.cloneBefore({
          selector: imgRuleSelectors
        }).removeAll();

        afterRule.append({
          prop: '-moz-box-shadow',
          value: 'inset 0 0 3em #222',
          prop: '-webkit-box-shadow',
          value: 'inset 0 0 3em #222'
        });

        origRule.append({
          prop: 'position',
          value: 'relative'
        });

        kalvinRule.append({
          prop: 'filter',
          value: 'sepia(0.3) saturate(2.2) brightness(1.3) contrast(1)'
        });

        decl.remove();
      };


      css.walkDecls('filter', function(decl) {
        switch (decl.value) {
          case 'kalvin':
            filterKalvin(decl);
            break;
        }
      });
    };
  });
